pub struct ConnectMobileCommand {
pub platform: i32,
pub device: Option<String>,
pub adb_endpoint: Option<String>,
pub preserve_app_state: bool,
pub retry_options: Option<CommandRetryOptions>,
}Fields
platform: i32device: Option<String>adb_endpoint: Option<String>preserve_app_state: boolretry_options: Option<CommandRetryOptions>Implementations
Sourceimpl ConnectMobileCommand
impl ConnectMobileCommand
Sourcepub fn platform(&self) -> MobilePlatform
pub fn platform(&self) -> MobilePlatform
Returns the enum value of platform, or the default if the field is set to an invalid enum value.
Sourcepub fn set_platform(&mut self, value: MobilePlatform)
pub fn set_platform(&mut self, value: MobilePlatform)
Sets platform to the provided enum value.
Sourcepub fn device(&self) -> &str
pub fn device(&self) -> &str
Returns the value of device, or the default value if device is unset.
Sourcepub fn adb_endpoint(&self) -> &str
pub fn adb_endpoint(&self) -> &str
Returns the value of adb_endpoint, or the default value if adb_endpoint is unset.