pub struct MobileConnectedEvent {
pub platform: i32,
pub device_name: String,
pub note: String,
pub device_id: String,
pub connection_kind: i32,
pub backend: String,
pub device_session_id: String,
pub initial_app_session_id: String,
pub package_name: Option<String>,
pub activity_name: Option<String>,
}Fields
platform: i32device_name: Stringnote: Stringdevice_id: Stringconnection_kind: i32backend: Stringdevice_session_id: Stringinitial_app_session_id: Stringpackage_name: Option<String>activity_name: Option<String>Implementations
Sourceimpl MobileConnectedEvent
impl MobileConnectedEvent
Sourcepub fn platform(&self) -> MobilePlatform
pub fn platform(&self) -> MobilePlatform
Returns the enum value of platform, or the default if the field is set to an invalid enum value.
Sourcepub fn set_platform(&mut self, value: MobilePlatform)
pub fn set_platform(&mut self, value: MobilePlatform)
Sets platform to the provided enum value.
Sourcepub fn connection_kind(&self) -> DeviceConnectionKind
pub fn connection_kind(&self) -> DeviceConnectionKind
Returns the enum value of connection_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_connection_kind(&mut self, value: DeviceConnectionKind)
pub fn set_connection_kind(&mut self, value: DeviceConnectionKind)
Sets connection_kind to the provided enum value.
Sourcepub fn package_name(&self) -> &str
pub fn package_name(&self) -> &str
Returns the value of package_name, or the default value if package_name is unset.
Sourcepub fn activity_name(&self) -> &str
pub fn activity_name(&self) -> &str
Returns the value of activity_name, or the default value if activity_name is unset.